@@ -17,7 +17,7 @@ use base qw(Exporter);    ## no critic (ProhibitUseBase)
 our @EXPORT_OK = 'breakdown';
 
 # Specify package version
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 # Dispatch table of functions to handle different ref types for the spec
 # hashref's values
@@ -35,9 +35,12 @@ my %types = (
         my $bounds = shift;
         @{$bounds} == 2
           or croak 'ARRAY ref for bounds needs two items';
-        my $l = defined $bounds->[0] ? $bounds->[0] : '-Inf';
-        my $u = defined $bounds->[1] ? $bounds->[1] : 'Inf';
-        return [ grep { $_ >= $l and $_ < $u } @_ ];
+        return [
+            grep {
+                      ( not defined $bounds->[0] or $_ >= $bounds->[0] )
+                  and ( not defined $bounds->[1] or $_ < $bounds->[1] )
+            } @_,
+        ];
     },
 
     # If it's a subroutine, return a arrayref of all elements for which it
@@ -101,7 +104,7 @@ List::Breakdown - Build sublist structures matching conditions
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =head1 DESCRIPTION
 
@@ -166,7 +169,7 @@ There are two shortcut syntaxes:
 
 If a value in the C<spec> structure is an C<ARRAY> reference with two items, it
 will be interpreted as defining bounds C<[lower,upper)> for matched values.
-`undef` can be used to denote negative or positive infinity.
+C<undef> can be used to denote negative or positive infinity.
 
 =item *
 
